﻿using System.Collections.ObjectModel;
using System.ComponentModel;
using GalaSoft.MvvmLight.Command;
using Infragistics.Controls.Grids;

namespace NavigationGrid 
{
    public class ViewModel : INotifyPropertyChanged
    {
        private ObservableCollection<Person> _listPersons;
        public ObservableCollection<Person> ListPersons
        {
            get { return _listPersons; }
            set
            {
                _listPersons = value;
                RaisePropertyChanged("ListPersons");
            }
        }

        private Person _persSelected;
        public Person PersSelected
        {
            get { return this._persSelected; }
            set
            {
                _persSelected = value;
                RaisePropertyChanged("PersSelected");
            }
        }

        public ViewModel()
        {
            this.AllerPremierCommand = new RelayCommand<object>(AllerPremier);
            this.AllerPrecedentCommand = new RelayCommand<object>(AllerPrecedent);
            this.AllerSuivantCommand = new RelayCommand<object>(AllerSuivant);
            this.AllerDernierCommand = new RelayCommand<object>(AllerDernier);
            this.ListPersons = new ObservableCollection<Person>();
            for (int i = 0; i < 10; i++)
                this.ListPersons.Add(new Person("PersonName" + i, "PersonSurname" + i));
        }

#region Commands
        public RelayCommand<object> AllerPremierCommand { get; set; }
        public RelayCommand<object> AllerPrecedentCommand { get; set; }
        public RelayCommand<object> AllerSuivantCommand { get; set; }
        public RelayCommand<object> AllerDernierCommand { get; set; }

        protected void AllerPremier(object o)
        {
            var grille = ((XamGrid)o);
            this.PersSelected = (Person)grille.Rows[0].Data;
            grille.Rows[grille.ActiveCell.Row.Index].IsSelected = true;
        }

        protected void AllerPrecedent(object o)
        {
            var grille = ((XamGrid)o);
            if (grille.Rows[grille.ActiveCell.Row.Index - 1] != null)
            {
                this.PersSelected = (Person)grille.Rows[grille.ActiveCell.Row.Index - 1].Data;
                grille.Rows[grille.ActiveCell.Row.Index].IsSelected = true;
            }
        }

        protected void AllerSuivant(object o)
        {
            var grille = ((XamGrid)o);

            //  Determine if the active cell is part of a GroupByRecord and not a DataRecord
            if (grille.ActiveCell is Infragistics.Controls.Grids.Primitives.GroupByCell)
            {
                return;
            }
            
            //You may need to do some additional coding when your don't have any GroupBy
            // but the idea is to determine how many rows are in the GroupByRow collection and then 
            // ...... move accordingly.

            //  I'm not sure if you want to go to the next group / first item or to the top of this group
            //  that code will depend on you.
            Infragistics.Controls.Grids.Primitives.GroupByRow gbr = (Infragistics.Controls.Grids.Primitives.GroupByRow)(grille.ActiveCell.Row as Infragistics.Controls.Grids.Row).ParentRow;
            if (gbr.GroupByData.Count > grille.ActiveCell.Row.Index + 1)
            {

            }   
            
            if (grille.Rows[grille.ActiveCell.Row.Index + 1] != null)
            {
                //  Determine if the active cell is part of a GroupByRecord and not a DataRecord
                if (grille.Rows[grille.ActiveCell.Row.Index + 1] is Infragistics.Controls.Grids.Primitives.GroupByRow ) 
                {
                   // you will have to determine what to do if the next row is a GroupByRow
                    return;
                }
                
                this.PersSelected = (Person)grille.Rows[grille.ActiveCell.Row.Index + 1].Data;
                grille.Rows[grille.ActiveCell.Row.Index].IsSelected = true;
            }
        }

        protected void AllerDernier(object o)
        {
            var grille = ((XamGrid)o);
            this.PersSelected = (Person)grille.Rows[grille.Rows.Count - 1].Data;
            grille.Rows[grille.ActiveCell.Row.Index].IsSelected = true;
        }

#endregion

        public event PropertyChangedEventHandler PropertyChanged;

        public void RaisePropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }
    }
}
